`termSim` <-
function(GOID1, GOID2, measure="Resnik", db="all") {
    go1<-get(GOID1, GOTERM)
    go2<-get(GOID2, GOTERM)
    wh_ont<-Ontology(go1)
    if(wh_ont != Ontology(go2)) 
        stop("GO terms should be in the same sub-ontology (BP, MF, or CC)!")	

    rootCount<-switch(wh_ont, 
        MF=.gocount["GO:0003674", db],
	BP=.gocount["GO:0008150", db],		
	CC=.gocount["GO:0005575", db] )

    p1<-.gocount[GOID1, db]/rootCount
    p2<-.gocount[GOID2, db]/rootCount
    if(is.na(p1) || is.na(p2)) return(NA)
    if((p1 == 0 || p2 == 0) && measure != 'Resnik') return(NA)

    dataenv<-get(paste("GO", wh_ont, "ANCESTOR", sep=""), mode="environment")
    ancestor1<-c(GOID1, get(GOID1, dataenv))
    ancestor2<-c(GOID2, get(GOID2, dataenv))
    commonAncestor<-intersect(ancestor1, ancestor2)

    pms<-min(.gocount[commonAncestor, db], na.rm=TRUE)/rootCount

    sim<-switch(measure,
        Resnik=-log(pms),
	Lin=2*log(pms)/(log(p1)+log(p2)),
	Jiang=2*log(pms)-log(p1)-log(p2), 
	Rel=(2*log(pms)/(log(p1)+log(p2)))*(1-pms) )	

    return(round(sim, digits=3))
}

